@@ -1,21 +1,32 @@
 extern crate jsonc_parser;
 
-use pretty_assertions::{assert_eq};
-use std::rc::Rc;
-use std::fs::{self};
-use std::path::{Path, PathBuf};
-use jsonc_parser::*;
 use jsonc_parser::ast::*;
 use jsonc_parser::common::*;
+use jsonc_parser::*;
+use pretty_assertions::assert_eq;
+use std::fs::{self};
+use std::path::{Path, PathBuf};
+use std::rc::Rc;
 
 #[test]
 fn test_specs() {
     for json_path in get_json_file_paths_in_dir(&Path::new("./tests/specs")) {
         let text_file_path = json_path.with_extension("txt");
-        let json_file_text = fs::read_to_string(&json_path).expect("Expected to read file.").replace("\r\n", "\n");
-        let result = parse_to_ast(&json_file_text, &ParseOptions { tokens: true, comments: true }).expect("Expected no error.");
+        let json_file_text = fs::read_to_string(&json_path)
+            .expect("Expected to read file.")
+            .replace("\r\n", "\n");
+        let result = parse_to_ast(
+            &json_file_text,
+            &ParseOptions {
+                tokens: true,
+                comments: true,
+            },
+        )
+        .expect("Expected no error.");
         let result_text = parse_result_to_test_str(&result);
-        let expected_text = fs::read_to_string(&text_file_path).expect("Expected to read expected file.").replace("\r\n", "\n");
+        let expected_text = fs::read_to_string(&text_file_path)
+            .expect("Expected to read expected file.")
+            .replace("\r\n", "\n");
         // fs::write(&text_file_path, result_text.clone()).unwrap();
         assert_eq!(result_text.trim(), expected_text.trim());
     }
@@ -51,15 +62,18 @@ fn get_json_file_paths_in_dir(path: &Path) -> Vec<PathBuf> {
 fn parse_result_to_test_str(parse_result: &ParseResult) -> String {
     let mut text = String::new();
     text.push_str("{\n");
-    text.push_str(&format!("  \"value\": {},\n", match &parse_result.value {
-        Some(value) => value_to_test_str(value).replace("\n", "\n  "),
-        None => String::from("null"),
-    }));
+    text.push_str(&format!(
+        "  \"value\": {},\n",
+        match &parse_result.value {
+            Some(value) => value_to_test_str(value).replace("\n", "\n  "),
+            None => String::from("null"),
+        }
+    ));
     text.push_str("  \"comments\": [");
     let comments = parse_result.comments.as_ref().expect("Expected comments.");
     let collection_count = comments.len();
     let mut comments = comments.iter().collect::<Vec<_>>();
-    comments.sort_by(|a, b|a.0.cmp(&b.0));
+    comments.sort_by(|a, b| a.0.cmp(&b.0));
     for (i, comment_collection) in comments.into_iter().enumerate() {
         text.push_str("\n    ");
         text.push_str(&comments_to_test_str(comment_collection).replace("\n", "\n    "));
@@ -143,9 +157,18 @@ fn object_prop_to_test_str(obj_prop: &ObjectProp) -> String {
     let mut text = String::new();
     text.push_str("{\n");
     text.push_str("  \"type\": \"objectProp\",\n");
-    text.push_str(&format!("  {},\n", range_to_test_str(&obj_prop.range).replace("\n", "\n  ")));
-    text.push_str(&format!("  \"name\": {},\n", object_prop_name_to_test_str(&obj_prop.name).replace("\n", "\n  ")));
-    text.push_str(&format!("  \"value\": {}\n", value_to_test_str(&obj_prop.value).replace("\n", "\n  ")));
+    text.push_str(&format!(
+        "  {},\n",
+        range_to_test_str(&obj_prop.range).replace("\n", "\n  ")
+    ));
+    text.push_str(&format!(
+        "  \"name\": {},\n",
+        object_prop_name_to_test_str(&obj_prop.name).replace("\n", "\n  ")
+    ));
+    text.push_str(&format!(
+        "  \"value\": {}\n",
+        value_to_test_str(&obj_prop.value).replace("\n", "\n  ")
+    ));
     text.push_str("}");
     text
 }
@@ -180,7 +203,10 @@ fn null_keyword_to_test_str(null_keyword: &NullKeyword) -> String {
     let mut text = String::new();
     text.push_str("{\n");
     text.push_str("  \"type\": \"null\",\n");
-    text.push_str(&format!("  {}\n", range_to_test_str(&null_keyword.range).replace("\n", "\n  ")));
+    text.push_str(&format!(
+        "  {}\n",
+        range_to_test_str(&null_keyword.range).replace("\n", "\n  ")
+    ));
     text.push_str("}");
     text
 }
@@ -219,11 +245,10 @@ fn comment_block_to_test_str(block: &CommentBlock) -> String {
 }
 
 fn escape_json_str(text: &str) -> String {
-    text
-        .replace("\\", "\\\\")
+    text.replace("\\", "\\\\")
         .replace("\x08", "\\b")
         .replace("\x0C", "\\f")
         .replace("\r", "\\r")
         .replace("\t", "\\t")
         .replace("\n", "\\n")
-}
\ No newline at end of file
+}
